.. _generate_cf_asymp_optimized:

`generate_cf_asymp_optimized`
=============================

.. automodule:: oasis_stat
   :members: generate_cf_asymp_optimized
   :undoc-members:
   :show-inheritance:
   :noindex:
   
Description
-----------
Generates optimized column and row embeddings for the asymptotic p-value on the input data. Tries multiple random initializations and returns the embeddings that maximize the asymp sample p-value on the given X.